@@ -9,6 +9,7 @@ from . import optim
 from . import preprocess
 from . import util
 from . import visualization
+from . import debug
 from .neko_module import NekoModule
 from .neko_model import NekoModel
 from .neko_trainer import NekoTrainer
@@ -25,6 +26,7 @@ __all__ = [
     "preprocess",
     "util",
     "visualization",
+    "debug",
     "NekoModel",
     "NekoTrainer",
     "NekoModule"
